.. image:: https://raw.githubusercontent.com/DevRopen/Hvitserk/refs/heads/main/static/cover.jpg
  :width: 700
  :alt: Alternative text

.. image:: https://img.shields.io/pypi/v/Hvitserk.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/Hvitserk/
.. image:: https://github.com/DevRopen/Hvitserk/actions/workflows/ci.yml/badge.svg?branch=main
    :alt: Build Status
    :target: https://github.com/DevRopen/Hvitserk/actions/workflows/ci.yml

|

========
Hvitserk
========

    Github Automation Package in Python Powered By AI.


Note
====

This Project is Read Only and a Part of Ropen Core.
